import setuptools

setuptools.setup(name='snm_build',
                 version='0.0.1',
                 description='Building and release project',
                 packages=setuptools.find_packages(),
                 install_requires=[],
                 author_email='serheos@gmail.com',
                 zip_safe=False)
